# This file was auto-generated by Fern from our API Definition.

from .comment_request import CommentRequest
from .comment_response import CommentResponse

__all__ = ["CommentRequest", "CommentResponse"]
